@@ -62,6 +62,7 @@
 //              2013-03-19  - Upgrade to SQLite3 version 3.7.16
 //              2013-08-29  - Upgrade to SQLite3 version 3.8.0
 //              2013-09-07  - Upgrade to SQLite3 version 3.8.0.2
+//              2013-12-08  - Upgrade to SQLite3 version 3.8.2
 //
 // Copyright:   (c) Ulrich Telle
 // Licence:     wxWindows licence
@@ -104,12 +105,16 @@
 
 <dl>
 
+<dt><b>3.0.6</b> - <i>December 2013</i></dt>
+<dd>
+Upgrade to SQLite version 3.8.2<br>
+
+</dd>
 <dt><b>3.0.5</b> - <i>September 2013</i></dt>
 <dd>
 Upgrade to SQLite version 3.8.0.2<br>
 Added support for setting the temporary directory for SQLite on Windows<br>
 
-
 </dd>
 <dt><b>3.0.4</b> - <i>August 2013</i></dt>
 <dd>
